Enum Request
#[non_exhaustive]pub enum Request {
Motion {
time: u32,
dx: f64,
dy: f64,
},
MotionAbsolute {
time: u32,
x: u32,
y: u32,
x_extent: u32,
y_extent: u32,
},
Button {
time: u32,
button: u32,
state: WEnum<ButtonState>,
},
Axis {
time: u32,
axis: WEnum<Axis>,
value: f64,
},
Frame,
AxisSource {
axis_source: WEnum<AxisSource>,
},
AxisStop {
time: u32,
axis: WEnum<Axis>,
},
AxisDiscrete {
time: u32,
axis: WEnum<Axis>,
value: f64,
discrete: i32,
},
Destroy,
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Motion
pointer relative motion event
The pointer has moved by a relative amount to the previous request.
Values are in the global compositor space.
Fields
MotionAbsolute
pointer absolute motion event
The pointer has moved in an absolute coordinate frame.
Value of x can range from 0 to x_extent, value of y can range from 0 to y_extent.
Fields
Button
button event
A button was pressed or released.
Fields
button that produced the event
Axis
axis event
Scroll and other axis requests.
Fields
Frame
end of a pointer event sequence
Indicates the set of events that logically belong together.
AxisSource
axis source event
Source information for scroll and other axis.
AxisStop
axis stop event
Stop notification for scroll and other axes.
Fields
AxisDiscrete
axis click event
Discrete step information for scroll and other axes.
This event allows the client to extend data normally sent using the axis event with discrete value.
Fields
Destroy
destroy the virtual pointer object
This is a destructor, once received this object cannot be used any longer.
Implementations